<TS language="ja" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>新規アドレスの作成</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新規(&amp;N)</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>現在選択されているアドレスをシステムのクリップボードにコピーする</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>コピー(&amp;C)</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>選択されたアドレスを一覧から削除する</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>削除(&amp;D)</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>ラベルをコピー (&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>編集 (&amp;E)</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>ラベル</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>アドレス</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ラベル無し)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>パスフレーズ ダイアログ</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>パスフレーズを入力</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>新しいパスフレーズ</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>新しいパスフレーズをもう一度</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>ウォレットの新しいパスフレーズを入力してください。&lt;br/&gt;&lt;b&gt;10文字以上のランダムな文字&lt;/b&gt;で構成されたものか、&lt;b&gt;8単語以上の単語&lt;/b&gt;で構成されたパスフレーズを使用してください。</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>ウォレットを暗号化する</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>この操作はウォレットをアンロックするためにパスフレーズが必要です。</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>ウォレットをアンロックする</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>パスフレーズの変更</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>ウォレットの暗号化を確認する</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>本当にウォレットを暗号化しますか?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>ウォレットは暗号化されました</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>重要: 過去のウォレット ファイルのバックアップは、暗号化された新しいウォレット ファイルに取り替える必要があります。セキュリティ上の理由により、暗号化された新しいウォレットを使い始めると、暗号化されていないウォレット ファイルのバックアップはすぐに使えなくなります。</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>ウォレットの暗号化に失敗しました</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>内部エラーによりウォレットの暗号化が失敗しました。ウォレットは暗号化されませんでした。</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>パスフレーズが同じではありません。</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>ウォレットのアンロックに失敗しました</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>ウォレットの暗号化解除のパスフレーズが正しくありません。</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>ウォレットのパスフレーズの変更が成功しました。</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>警告: Caps Lock キーがオンになっています!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>ウォレット</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>概要(&amp;O)</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>ウォレットの概要を見る</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>送金 (&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>入金 (&amp;R)</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>取引履歴を閲覧</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>終了(&amp;E)</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>アプリケーションを終了</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>オプション... (&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>見る/隠す (&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>ウォレットの暗号化... (&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>パスフレーズの変更... (&amp;C)</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>ウォレット暗号化用パスフレーズの変更</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>メッセージの署名... (&amp;m)</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>メッセージの検証... (&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>デバッグ ウインドウ (&amp;D)</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>デバッグと診断コンソールを開く</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>設定(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>バージョンは最新です</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>追跡中...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>送金取引</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>着金取引</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>ウォレットは&lt;b&gt;暗号化されて、ロックされています&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>数量:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>バイト:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>総額:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>手数料:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>手数料差引後:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>釣り銭:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>総額</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>日付</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>検証数</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>検証済み</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>アドレスをコピーする</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>ラベルをコピーする</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>総額のコピー</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>取引 ID をコピー</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>数量をコピーする</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>手数料をコピーする</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>手数料差引後の値をコピーする</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>バイト数をコピーする</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>釣り銭をコピー</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>はい</translation>
    </message>
    <message>
        <source>no</source>
        <translation>いいえ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>（ラベル無し）</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>%1 (%2) からのおつり</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(おつり)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>アドレスの編集</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>ラベル(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>アドレス帳 (&amp;A)</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>新しい受信アドレス</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>新しい送信アドレス</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>入金アドレスを編集</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>送信アドレスを編集</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>入力されたアドレス "%1" は既にアドレス帳にあります。</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>ウォレットをアンロックできませんでした。</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>新しいキーの生成に失敗しました。</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>メイン (&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>ネットワーク (&amp;N)</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>UPnP を使ってポートを割り当てる (&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>ポート (&amp;P) :</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>プロキシのポート番号 (例 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>ウインドウ (&amp;W)</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>ウインドウを最小化したあとトレイ アイコンだけを表示する。</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>タスクバーの代わりにトレイに最小化 (&amp;M)</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>閉じる時に最小化 (&amp;i)</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>表示 (&amp;D)</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>ユーザインターフェースの言語 (&amp;l) :</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>額を表示する単位 (&amp;U) :</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>インターフェース上の表示とコインの送信で使用する単位を選択します。</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>キャンセル (&amp;C)</translation>
    </message>
    <message>
        <source>default</source>
        <translation>初期値</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>プロキシアドレスが無効です。</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>フォーム</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>利用可能:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>あなたの利用可能残高</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>未完成:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>合計:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>あなたの現在の残高</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation>クライアントのバージョン</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>情報 (&amp;I)</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>起動した日時</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>接続数</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>ブロック チェーン</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>現在のブロック数</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>最終ブロックの日時</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>開く (&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>クリア(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>コンソール (&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>ネットワーク (&amp;N)</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>合計</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>入力:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>出力:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>デバッグ用ログファイル</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>コンソールをクリア</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>上下の矢印で履歴をたどれます。 &lt;b&gt;Ctrl-L&lt;/b&gt; でスクリーンを消去できます。</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>使用可能なコマンドを見るには &lt;b&gt;help&lt;/b&gt; と入力します。</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>コインを送る</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>入力...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>自動選択</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>残高不足です！</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>数量:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>バイト:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>総額:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>手数料:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>手数料差引後:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>一度に複数の人に送る</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>受取人を追加 (&amp;R)</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>すべてクリア (&amp;A)</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>送る操作を確認する</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>送金 (&amp;E)</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>数量をコピーする</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>総額のコピー</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>手数料をコピーする</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>手数料差引後の値をコピーする</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>バイト数をコピーする</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>釣り銭をコピー</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>コインを送る確認</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>支払額は0より大きくないといけません。</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>額が残高を超えています。</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>%1 の取引手数料を含めると額が残高を超えています。</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>（ラベル無し）</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>金額(&amp;A):</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>送り先(&amp;T):</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>メッセージ:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>ラベル(&amp;L):</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>クリップボードからアドレスを貼付ける</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>アドレス帳に追加するには、このアドレスのラベルを入力します</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>署名 - メッセージの署名/検証</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>メッセージの署名 (&amp;S)</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>クリップボードからアドレスを貼付ける</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>ここにあなたが署名するメッセージを入力します</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>現在の署名をシステムのクリップボードにコピーする</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>メッセージの署名 (&amp;M)</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>入力項目の内容をすべて消去します</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>すべてクリア (&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>メッセージの検証 (&amp;V)</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>入力項目の内容をすべて消去します</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>署名を作成するには"メッセージの署名"をクリック</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>不正なアドレスが入力されました。</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>アドレスを確かめてからもう一度試してください。</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>入力されたアドレスに関連するキーがありません。</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>ウォレットのアンロックはキャンセルされました。</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>入力されたアドレスのプライベート キーが無効です。</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>メッセージの署名に失敗しました。</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>メッセージに署名しました。</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>署名がデコードできません。</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>署名を確認してからもう一度試してください。</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>署名はメッセージ ダイジェストと一致しませんでした。</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>メッセージの検証に失敗しました。</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>メッセージは検証されました。</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>ユニット %1 を開く</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1/オフライン</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/未検証</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 確認</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>ステータス</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>まだブロードキャストが成功していません</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>日付</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>ソース</translation>
    </message>
    <message>
        <source>From</source>
        <translation>送信</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>未確認</translation>
    </message>
    <message>
        <source>To</source>
        <translation>受信</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>自分のアドレス</translation>
    </message>
    <message>
        <source>label</source>
        <translation>ラベル</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>クレジット</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>承認されなかった</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>引き落とし額</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>取引手数料</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>正味金額</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>メッセージ</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>コメント</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>総額</translation>
    </message>
    <message>
        <source>true</source>
        <translation>正しい</translation>
    </message>
    <message>
        <source>false</source>
        <translation>正しくない</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>ここでは取引の詳細を表示しています</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>日付</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>タイプ</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>ユニット %1 を開く</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>オフライン</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>未検証</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>検証されました (%1 検証済み)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>衝突</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>生成されましたが承認されませんでした</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>送り主</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>送り主</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>送り先</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>自分自身への支払い</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>取引の状況。このフィールドの上にカーソルを置くと検証の数を表示します。</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>取引を受信した日時。</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>取引の種類。</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>残高に追加または削除された総額。</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>今日</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>今週</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>今月</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>先月</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>今年</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>期間...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>送り主</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>送り先</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>自分自身</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>発掘した</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>その他</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>最小の額</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>アドレスをコピーする</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>ラベルをコピーする</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>総額のコピー</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>取引 ID をコピー</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>ラベルの編集</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>取引の詳細を表示</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>検証済み</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>日付</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>タイプ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ラベル</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>アドレス</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>期間:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>から</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>ポートのリスンに失敗しました。必要であれば -listen=0 を使用してください。</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>無効な -proxy アドレス: '%s'</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>アドレスを読み込んでいます...</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>-onlynet で指定された '%s' は未知のネットワークです</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>残高不足</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>ブロック インデックスを読み込んでいます...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>ウォレットを読み込んでいます...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>初期値のアドレスを書き込むことができません</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>再スキャン中...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>読み込み完了</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
</context>
</TS>